function [] = plotSoundsourceToaFromGps(soundsources)
%PLOTSOUNDSOURCETOAFROMGPS Summary of this function goes here
%   Detailed explanation goes here

global artoaDataInput artoaWorkspace artoaGui;


hold(artoaGui.figures.editTimeOfArrival.CurrentAxes, 'on');

%% Collect required data
yMax = max(artoaGui.figures.editTimeOfArrival.CurrentAxes.YLim);
yMin = min(artoaGui.figures.editTimeOfArrival.CurrentAxes.YLim);



for o = 1:length(soundsources)
    % skip sound source if it went out of the water before the float range, or
    % went in the water after the float range
    soundSourceBegin = artoa.convert.dmy2rd(artoaDataInput.soundsources.(soundsources{o}).begemis(3), ...
        artoaDataInput.soundsources.(soundsources{o}).begemis(2), ...
        artoaDataInput.soundsources.(soundsources{o}).begemis(1));
    soundSourceEnd = artoa.convert.dmy2rd(artoaDataInput.soundsources.(soundsources{o}).endemis(3), ...
        artoaDataInput.soundsources.(soundsources{o}).endemis(2), ...
        artoaDataInput.soundsources.(soundsources{o}).endemis(1)); 
    if soundSourceEnd < min(artoaWorkspace.toaData.toaDate) ...
        || soundSourceBegin > max(artoaWorkspace.toaData.toaDate)
        continue;
    end

    [gpsDates, predictedToas] = artoa.data.predictToaFromGps( ...
        artoaDataInput.rfb, artoaDataInput.soundsources.(soundsources{o}), ...
        struct( ...
            'temperature', artoaWorkspace.temperature(artoaWorkspace.statusTemperature == 1), ...
            'pressure', artoaWorkspace.pressure(artoaWorkspace.statusPressure == 1), ...
            'method', 'del grosso', ...
            'soundSource', NaN ...
        ) ...
    );

    % remove gps dates that are past end mission of sound source
    selection = (gpsDates > soundSourceEnd);
    gpsDates(selection) = NaN;
    predictedToas(selection) = NaN;
    clear selection;

    scatter( ...
        artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
        gpsDates, predictedToas, 20, ...
        'MarkerFaceColor', [1 1 1] ...
    );
    text( ...
        artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
        gpsDates, predictedToas, ['-', soundsources{o}], ...¬                                                                                        
        'HorizontalAlignment', 'left', ...¬                               
        'VerticalAlignment', 'top', ...¬                                 
        'FontName', 'Helvetica', ...¬                                     
        'FontSize', 10, ...¬                                              
        'FontWeight', 'demi', ...¬                                        
        'Color', [1 1 1] ...
    );
    
    % Soundsource lines
    % define step size of the text for sound source lines
    tmpSteps = floor((yMax - yMin)/10);
    additionalYOffset = o*(tmpSteps/length(soundsources));
    % deployment
    toaMax = max(artoaWorkspace.toaData.toaDate(artoaWorkspace.toaData.status ~= 2));
    toaMin = min(artoaWorkspace.toaData.toaDate(artoaWorkspace.toaData.status ~= 2));
    toaExtension = 10;
    if (soundSourceBegin > toaMin - toaExtension) ...
            && (soundSourceBegin < toaMax + toaExtension)
        for textSteps = yMin:tmpSteps:(yMax-tmpSteps)
            text( ...
                artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
                soundSourceBegin, textSteps + additionalYOffset, ...
                ['<-- ', soundsources{o}], ...
                'Color',[1 .4 .4], ...
                'HorizontalAlignment', 'center', ...
                'VerticalAlignment', 'bottom', ...
                'FontName', 'Helvetica', ...
                'FontSize', 10, ...
                'FontWeight', 'demi', ...
                'Rotation', 90 ...
            );
        end
        plot( ...
            artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
            [soundSourceBegin soundSourceBegin], [yMax yMin], ...
            'color', [1 .4 .4], ...
            'LineStyle', '-.' ...
        );
    end
    % recovering
    if (soundSourceEnd > toaMin - toaExtension) ...
            && (soundSourceEnd < toaMax + toaExtension)
        for textSteps = yMin:tmpSteps:(yMax-tmpSteps)
            text( ...
                artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
                soundSourceEnd, textSteps + additionalYOffset, ...
                [soundsources{o}, ' -->'], ...
                'Color',[1 .4 .4], ...
                'HorizontalAlignment', 'center', ...
                'VerticalAlignment', 'bottom', ...
                'FontName', 'Helvetica', ...
                'FontSize', 10, ...
                'FontWeight', 'demi', ...
                'Rotation', 90 ...
            );
        end
        plot( ...
            artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
            [soundSourceEnd soundSourceEnd], [yMax yMin], ...
            'color', [1 .4 .4], ...
            'LineStyle', '-.' ...
        );
    end
end

hold(artoaGui.figures.editTimeOfArrival.CurrentAxes, 'off');


end

